@@ -68,17 +68,25 @@ def ajax_login(request, redirect_field_name=REDIRECT_FIELD_NAME, form_class=User
 
 @csrf_protect
 @json_view
-def ajax_registration(request, form_class=UserRegistrationForm):
+def ajax_registration(request, form_class=UserRegistrationForm,
+                    redirect_to='/accounts/registration/complete/'):
     if request.method == 'POST':
         form = form_class(data=request.POST, files=request.FILES)
         if form.is_valid():
             form.save()
-            return {'success': True, 'redirect_to': '/'}
+            return {'success': True, 'redirect_to': redirect_to}
         else:
             form_html = render_crispy_form(form)
             return {'success': False, 'form_html': form_html}
 
 
+def registration_complete(request, template_name='accounts/registration_complete.html',
+                        **kwargs):
+    return render_to_response(template_name,
+                              kwargs,
+                              context_instance=RequestContext(request))
+
+
 def activate(request, template_name='accounts/activate.html',
              success_url=None, extra_context=None, **kwargs):
     user = get_user_model().objects.activate_user(**kwargs)
